@@ -7,7 +7,7 @@ use Encode;
 use File::Spec;
 use YAML::Tiny ();
 
-our $VERSION = '0.0.11';
+our $VERSION = '0.0.12';
 
 __PACKAGE__->setting(
     handle_static => 1,
@@ -107,7 +107,9 @@ Riji - Simple, git based blog tool
 
 =head1 TUTORIAL
 
-L<http://songmu.github.io/p5-Riji/blog/> japanese only...
+Japanese: L<http://songmu.github.io/p5-Riji/blog/>
+
+English L<http://perlmaven.com/blogging-with-riji>
 
 =head1 DESCRIPTION
 
@@ -124,6 +126,10 @@ Copyright (C) Masayuki Matsuki.
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 THANKS
+
+Thanks to Gabor Szabo E<lt>szabgab@gmail.comE<gt> for great English tutorial.
+
 =head1 AUTHOR
 
 Masayuki Matsuki E<lt>y.songmu@gmail.comE<gt>
